==> haskell-heapsize-0.3.0.1-298-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-heapsize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 heapsize
version:              0.3.0.1
visibility:           public
id:                   heapsize-0.3.0.1-CrbkZq5QSpvJzeOjfKlUwj
key:                  heapsize-0.3.0.1-CrbkZq5QSpvJzeOjfKlUwj
license:              BSD-3-Clause
copyright:
    Dennis Felsing 2012-2019, Michail Pardalos 2020, Pepe Iborra 2020-2021

maintainer:           Pepe Iborra <pepeiborra@gmail.com>
author:               Michail Pardalos <mpardalos@gmail.com>
synopsis:             Determine the size of runtime data structures
description:
    heapsize is a tool to determine the size data structures.
    Determining the size of recursive data structures is
    supported. All sizes are in Bytes.

category:             GHC, Debug, Development
abi:                  9ed6120a128b70b5ca63d4b6e1c46498
exposed:              True
exposed-modules:      HeapSize
import-dirs:          /usr/lib/ghc-9.4.8/site-local/heapsize-0.3.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/heapsize-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/heapsize-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-heapsize
hs-libraries:         HSheapsize-0.3.0.1-CrbkZq5QSpvJzeOjfKlUwj
depends:
    base-4.17.2.1 deepseq-1.4.8.0 exceptions-0.10.5 ghc-heap-9.4.8
    hashable-1.4.4.0-GlxcJ9XR4pRDbsSt4txSan
    hashtables-1.4.1-ASZuGrURD4BHEOZK79zTN9
    primitive-0.9.1.0-8CfYwbRaTKl361HTr6YpqL transformers-0.5.6.2
    unordered-containers-0.2.20-3ZBRQjn1NdW5zFXXpEAC63

haddock-interfaces:   /usr/share/doc/haskell-heapsize/html/heapsize.haddock
haddock-html:         /usr/share/doc/haskell-heapsize/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-heapsize-0.3.0.1-299-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-heapsize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 heapsize
version:              0.3.0.1
visibility:           public
id:                   heapsize-0.3.0.1-Eivwi82NDO2IufLG3w4sFk
key:                  heapsize-0.3.0.1-Eivwi82NDO2IufLG3w4sFk
license:              BSD-3-Clause
copyright:
    Dennis Felsing 2012-2019, Michail Pardalos 2020, Pepe Iborra 2020-2021

maintainer:           Pepe Iborra <pepeiborra@gmail.com>
author:               Michail Pardalos <mpardalos@gmail.com>
synopsis:             Determine the size of runtime data structures
description:
    heapsize is a tool to determine the size data structures.
    Determining the size of recursive data structures is
    supported. All sizes are in Bytes.

category:             GHC, Debug, Development
abi:                  2ac020492d64fce363c5ece85e637cc6
exposed:              True
exposed-modules:      HeapSize
import-dirs:          /usr/lib/ghc-9.4.8/site-local/heapsize-0.3.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/heapsize-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/heapsize-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-heapsize
hs-libraries:         HSheapsize-0.3.0.1-Eivwi82NDO2IufLG3w4sFk
depends:
    base-4.17.2.1 deepseq-1.4.8.0 exceptions-0.10.5 ghc-heap-9.4.8
    hashable-1.4.4.0-DGEtQXeqhKmCCbhJMtBsUM
    hashtables-1.4.1-1eLblsQ2mKIED4KsDc1hl9
    primitive-0.9.1.0-3zmpEdmoBvMCFbJpHhp8DL transformers-0.5.6.2
    unordered-containers-0.2.20-8Q4WKXtMGLf6eJrIPiNhPJ

haddock-interfaces:   /usr/share/doc/haskell-heapsize/html/heapsize.haddock
haddock-html:         /usr/share/doc/haskell-heapsize/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
